@@ -252,6 +252,8 @@ class PathzPath(Path, PathzPurePath):
         the built-in open() function does.
         """
         if self._closed: self._raise_closed()
+        if 'b' in mode:
+            return io.open(self, mode = mode, buffering = buffering, opener=self._opener)
         return io.open(self, mode, buffering, encoding, errors, newline, opener=self._opener)
 
     
@@ -260,6 +262,8 @@ class PathzPath(Path, PathzPurePath):
         Asyncronously Open the file pointed by this path and return a file object, as
         the built-in open() function does.
         """
+        if 'b' in mode:
+            return get_handle(self._path, mode = mode, buffering = buffering)
         return get_handle(self._path, mode, encoding=encoding, errors=errors, newline=newline)
     
     def reader(self, mode: FileMode = 'r', buffering: int = -1, encoding: Optional[str] = DEFAULT_ENCODING, errors: Optional[str] = ON_ERRORS, newline: Optional[str] = NEWLINE, **kwargs) -> IO[Union[str, bytes]]:
@@ -1167,7 +1171,7 @@ class PathzPath(Path, PathzPurePath):
         Writes JSON to File
         """
         with self.open('w', encoding = encoding) as f:
-            f.write(Serialize.Json.dumps(data, ensure_ascii=ensure_ascii, indent=indent, **kwargs))
+            f.write(Serialize.SimdJson.dumps(data, ensure_ascii=ensure_ascii, indent=indent, **kwargs))
     
     def write_jsonlines(self, data: List[JsonType], append: bool = False, encoding: Optional[str] = DEFAULT_ENCODING, newline: str = '\n', ignore_errors: bool = True, ensure_file_exists: bool = True, flush_every: int = 0, log_errors: bool = False, **kwargs):
         """
@@ -1234,7 +1238,7 @@ class PathzPath(Path, PathzPurePath):
         Writes JSON to File Asyncronously
         """
         async with self.async_open('w', encoding = encoding) as f:
-            await f.write(await Serialize.Json.async_dumps(data, ensure_ascii=ensure_ascii, indent=indent, **kwargs))
+            await f.write(await Serialize.SimdJson.async_dumps(data, ensure_ascii=ensure_ascii, indent=indent, **kwargs))
     
     async def async_write_jsonlines(self, data: List[JsonType], append: bool = False, encoding: Optional[str] = DEFAULT_ENCODING, newline: str = '\n', ignore_errors: bool = True, ensure_file_exists: bool = True, flush_every: int = 0, log_errors: bool = False, **kwargs):
         """
